@@ -12,6 +12,8 @@
 */
 
 #include "smtpconfigwidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "ui_smtpsettings.h"
 
 #include "mailtransport_defs.h"
@@ -26,6 +28,7 @@
 
 #include "mailtransport_debug.h"
 #include <KAuthorized>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KProtocolInfo>
 
@@ -137,7 +140,8 @@ void SMTPConfigWidget::init()
     d->serverTestFailed = false;
 
     d->ui.setupUi(this);
-    d->ui.password->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
+    d->ui.password->setRevealPasswordMode(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")) ? KPassword::RevealMode::OnlyNew
+                                                                                                             : KPassword::RevealMode::Never);
     d->manager->addWidget(this); // otherwise it doesn't find out about these widgets
     d->manager->updateWidgets();
 
@@ -153,9 +157,11 @@ void SMTPConfigWidget::init()
     d->ui.encryptionSsl->setChecked(d->transport->encryption() == Transport::EnumEncryption::SSL);
     d->ui.encryptionTls->setChecked(d->transport->encryption() == Transport::EnumEncryption::TLS);
 
+    d->ui.checkCapabilitiesProgress->setFormat(i18nc("Percent value; %p is the value, % is the percent sign", "%p%"));
+
     d->resetAuthCapabilities();
 
-    if (!KProtocolInfo::capabilities(SMTP_PROTOCOL).contains(QLatin1String("SASL"))) {
+    if (!KProtocolInfo::capabilities(SMTP_PROTOCOL).contains("SASL"_L1)) {
         d->ui.authCombo->removeItem(d->ui.authCombo->findData(Transport::EnumAuthenticationType::NTLM));
         d->ui.authCombo->removeItem(d->ui.authCombo->findData(Transport::EnumAuthenticationType::GSSAPI));
     }
